Module: TurboRspec::Matchers
- Defined in:
- lib/turbo_rspec/matchers.rb,
lib/turbo_rspec/matchers/have_turbo_frame.rb,
lib/turbo_rspec/matchers/have_turbo_stream.rb,
lib/turbo_rspec/matchers/have_turbo_streams.rb,
lib/turbo_rspec/matchers/match_turbo_stream_snapshot.rb,
lib/turbo_rspec/matchers/have_broadcasted_turbo_stream_to.rb
Overview
RSpec matchers for Turbo Stream and Turbo Frame assertions. Auto-included in +type: :request+ and +type: :controller+ example groups. Include explicitly for other contexts:
RSpec.configure do |config| config.include TurboRspec::Matchers end
Defined Under Namespace
Classes: HaveBroadcastedTurboStreamTo, HaveTurboFrame, HaveTurboStream, HaveTurboStreams, MatchTurboStreamSnapshot
Instance Method Summary collapse
-
#have_broadcasted_turbo_stream_to(stream_or_object) ⇒ HaveBroadcastedTurboStreamTo
(also: #broadcast_turbo_stream_to)
Assert that a block broadcasts a +
+ to the given stream. -
#have_turbo_frame ⇒ HaveTurboFrame
Assert that a response body contains a +
+ element. -
#have_turbo_stream ⇒ HaveTurboStream
(also: #assert_no_turbo_stream)
Assert that a response body contains a +
+ element. -
#have_turbo_streams(*matchers) ⇒ HaveTurboStreams
Assert that a response body contains all of the given turbo streams.
-
#match_turbo_stream_snapshot(name) ⇒ MatchTurboStreamSnapshot
Assert that a response body matches a stored turbo stream snapshot.
Instance Method Details
#have_broadcasted_turbo_stream_to(stream_or_object) ⇒ HaveBroadcastedTurboStreamTo Also known as: broadcast_turbo_stream_to
Assert that a block broadcasts a +
21 22 23 |
# File 'lib/turbo_rspec/matchers.rb', line 21 def have_broadcasted_turbo_stream_to(stream_or_object) HaveBroadcastedTurboStreamTo.new(stream_or_object) end |
#have_turbo_frame ⇒ HaveTurboFrame
Assert that a response body contains a +
30 31 32 |
# File 'lib/turbo_rspec/matchers.rb', line 30 def have_turbo_frame HaveTurboFrame.new end |
#have_turbo_stream ⇒ HaveTurboStream Also known as: assert_no_turbo_stream
Assert that a response body contains a +
36 37 38 |
# File 'lib/turbo_rspec/matchers.rb', line 36 def have_turbo_stream HaveTurboStream.new end |
#have_turbo_streams(*matchers) ⇒ HaveTurboStreams
Assert that a response body contains all of the given turbo streams.
47 48 49 |
# File 'lib/turbo_rspec/matchers.rb', line 47 def have_turbo_streams(*matchers) HaveTurboStreams.new(matchers) end |
#match_turbo_stream_snapshot(name) ⇒ MatchTurboStreamSnapshot
Assert that a response body matches a stored turbo stream snapshot. Creates the snapshot on the first run; diffs against it on subsequent runs. Set +UPDATE_TURBO_SNAPSHOTS=1+ to overwrite an existing snapshot.
56 57 58 |
# File 'lib/turbo_rspec/matchers.rb', line 56 def match_turbo_stream_snapshot(name) MatchTurboStreamSnapshot.new(name) end |